.onLoad = function(lib, pkg) {
  .bef.env$.bef.opts = list(
    url = "http://befdataproduction.biow.uni-leipzig.de",
    tematres_url = "http://befdataproduction.biow.uni-leipzig.de:7070/vocab/index.php",
    tematres_service_url = "http://befdataproduction.biow.uni-leipzig.de:7070/vocab/services.php",
    download_dir = "downloads",
    user_credentials = ""
  )
}
